==> wood-product-1.0.23.zip: src/function.php <==
<?php
    // this should only be used for testing purposes
    if (defined('TEST_ENV')) {
        //require_once __DIR__ . '/../../orbit-core/src/config.php';
        // Flexible path resolution for core files
        if (file_exists(__DIR__ . '\..\..\core\src\Fcors.php')) {
            require_once __DIR__ . '\..\..\core\src\Fcors.php';
        } else {
            require_once __DIR__ . '\..\..\core\Fcors.php';
        }
        require_once __DIR__ . '\..\..\core\unit-test\scripts\bootstrap.php';
        // Flexible path resolution for core files
        if (file_exists(__DIR__ . '\..\..\core\src\generic.php')) {
            require_once __DIR__ . '\..\..\core\src\generic.php';
        } else {
            require_once __DIR__ . '\..\..\core\generic.php';
        }
        $testInfo['0'] = ("\nFunction Running in Test Environment\n");
    } else {
        // this is code for live environment Dev, Uat, Production
        require_once __DIR__ . "./../error_monitor.php";
        require_once __DIR__ . "./../generic.php";
    }
    
    require_once __DIR__ . "/core.php";
    require_once __DIR__ . "/view.php";
    require_once __DIR__ . "/insert.php";
    require_once __DIR__ . "/update.php";

    $inputData = initializeGeneric();  // ✅ Ensures fresh initialization in each test

    $inputData['requiresAdmin'] = 
        [ 
            'productUpdate'     =>  [1,2,3,4,5],          'brandCreate' => [1,2,3,4,5],     'brandUpdate'   => [1,2,3,4,5], 
            'productCreate'     =>  [1,2,3,4,5],          'brandDelete' => [1,2,3,4,5],     'productDelete' => [1,2,3,4,5],
            'dimensionDelete'   =>  [1,2,3,4,5],          'priceDelete' => [1,2,3,4,5]
        ];


    $inputData['keepLive'] = checkLive();
    if(!isset($inputData['action']) || empty($inputData['action'])){
        $out['status']   = 'failed';
        $out['message']  = 'No Action Found';
        echo json_encode(propagateStatusAndMessage($out));
        exit;
    }

    $action = $inputData['action'];

    // check if action need auth and if does check it valid otherwise move to swithc statments 
    $security = SecurityCheck($inputData); // skip security for a bit 

    if($security['security'] === '1'){
        switch ($action) {
            case "brandCreate":
                $out = newBrand($inputData);
                break;
            case "productCreate":
                $out = newProduct($inputData);
                break;
            case "productBrandView":
                $out = viewPageBrands($inputData);
                break;
            case "productInfoFromBrand":
                $out = viewProductInfoFromBrand($inputData);
                break;
            case "productUpdate":
                $inputData['nextOperation'] = 'contentChange';
                $inputData['type']          = 'UPDATE'; // type of change 
                $inputData['followUp']      = 'update'; // next operation to run 
                $out = executeDatabaseOperation($inputData);
                break;
            case "brandUpdate":
                $out = updateBrand($inputData);
                break;
            case "brandDelete":
                $out = deleteBrand($inputData);
                break;
            case "productDelete":
                $inputData['nextOperation'] = 'contentChange';
                $inputData['type']          = 'DELETE'; // did not work as expected 
                $inputData['followUp']      = 'deleteProduct';
                $inputData['id']            = $inputData['productId'];
                $out = executeDatabaseOperation($inputData);
                //$data = deleteProduct($inputData); // revert if failes 
                break;
            /*
            case "dimensionDelete": // Not used anymore
                $out = deleteDimension($inputData);
                break;
            case "priceDelete": // Not used anymore
                $out = deletePrice($inputData);
                break;
            */
            default:
                $out = failed($inputData);
                break;
        }
    }else{
        $out = $security;
    }

   echo json_encode(propagateStatusAndMessage($out));
?>

==> wood-product-1.0.26.zip: src/function.php <==
<?php
    // this should only be used for testing purposes
    if (defined('TEST_ENV')) {
        //require_once __DIR__ . '/../../orbit-core/src/config.php';
        // Flexible path resolution for core files
        if (file_exists(__DIR__ . '\..\..\core\src\Fcors.php')) {
            require_once __DIR__ . '\..\..\core\src\Fcors.php';
        } else {
            require_once __DIR__ . '\..\core\Fcors.php';
        }
        require_once __DIR__ . '\..\..\core\unit-test\scripts\bootstrap.php';
        // Flexible path resolution for core files
        if (file_exists(__DIR__ . '\..\..\core\src\generic.php')) {
            require_once __DIR__ . '\..\..\core\src\generic.php';
        } else {
            require_once __DIR__ . '\..\core\generic.php';
        }
        $testInfo['0'] = ("\nFunction Running in Test Environment\n");
    } else {
        // this is code for live environment Dev, Uat, Production
        require_once __DIR__ . "./../error_monitor.php";
        require_once __DIR__ . "./../generic.php";
    }
    
    require_once __DIR__ . "/core.php";
    require_once __DIR__ . "/view.php";
    require_once __DIR__ . "/insert.php";
    require_once __DIR__ . "/update.php";

    $inputData = initializeGeneric();  // ✅ Ensures fresh initialization in each test

    $inputData['requiresAdmin'] = 
        [ 
            'productUpdate'     =>  [1,2,3,4,5],          'brandCreate' => [1,2,3,4,5],     'brandUpdate'   => [1,2,3,4,5], 
            'productCreate'     =>  [1,2,3,4,5],          'brandDelete' => [1,2,3,4,5],     'productDelete' => [1,2,3,4,5],
            'dimensionDelete'   =>  [1,2,3,4,5],          'priceDelete' => [1,2,3,4,5]
        ];


    $inputData['keepLive'] = checkLive();
    if(!isset($inputData['action']) || empty($inputData['action'])){
        $out['status']   = 'failed';
        $out['message']  = 'No Action Found';
        echo json_encode(propagateStatusAndMessage($out));
        exit;
    }

    $action = $inputData['action'];

    // check if action need auth and if does check it valid otherwise move to swithc statments 
    $security = SecurityCheck($inputData); // skip security for a bit 

    if($security['security'] === '1'){
        switch ($action) {
            case "brandCreate":
                $out = newBrand($inputData);
                break;
            case "productCreate":
                $out = newProduct($inputData);
                break;
            case "productBrandView":
                $out = viewPageBrands($inputData);
                break;
            case "productInfoFromBrand":
                $out = viewProductInfoFromBrand($inputData);
                break;
            case "productUpdate":
                $inputData['nextOperation'] = 'contentChange';
                $inputData['type']          = 'UPDATE'; // type of change 
                $inputData['followUp']      = 'update'; // next operation to run 
                $out = executeDatabaseOperation($inputData);
                break;
            case "brandUpdate":
                $out = updateBrand($inputData);
                break;
            case "brandDelete":
                $out = deleteBrand($inputData);
                break;
            case "productDelete":
                $inputData['nextOperation'] = 'contentChange';
                $inputData['type']          = 'DELETE'; // did not work as expected 
                $inputData['followUp']      = 'deleteProduct';
                $inputData['id']            = $inputData['productId'];
                $out = executeDatabaseOperation($inputData);
                //$data = deleteProduct($inputData); // revert if failes 
                break;
            /*
            case "dimensionDelete": // Not used anymore
                $out = deleteDimension($inputData);
                break;
            case "priceDelete": // Not used anymore
                $out = deletePrice($inputData);
                break;
            */
            default:
                $out = failed($inputData);
                break;
        }
    }else{
        $out = $security;
    }

   echo json_encode(propagateStatusAndMessage($out));
?>
